# Changes

## 2021-05-19

- Add MemorySource to fetch database into RAM before querying

## 2018-03-03

- Auto expanduser path.

## 2018-01-24

- First release to PyPI

## 2015-09-09

- Reorganise project structure

